@@ -5,10 +5,13 @@
 
 
 from dataclasses import asdict, dataclass, field
+from typing import Callable, Optional, Tuple
 
 from pythonosc.osc_message import OscMessage
 from pythonosc.osc_message_builder import OscMessageBuilder
 
+from . import responses
+
 
 @dataclass
 class OSCCommand:
@@ -23,6 +26,8 @@ class OSCCommand:
         # Extract the values
         # Code is largely copy-paste from pythonosc.UDPClient
         address = builder_dict.pop("address")
+        builder_dict.pop("callback", None)
+        builder_dict.pop("response_cls", None)
 
         builder = OscMessageBuilder(address=address)
 
@@ -39,6 +44,8 @@ class OSCCommand:
 
         # Convert the builder to a dictionary
         builder_dict = asdict(self)
+        builder_dict.pop("callback", None)
+        builder_dict.pop("response_cls", None)
 
         # Extract the values
         address: str = builder_dict.pop("address") + " "
@@ -47,6 +54,8 @@ class OSCCommand:
         for v in builder_dict.values():
             if isinstance(v, bool):
                 v = int(v)
+            if v is None:
+                continue
             address += str(v) + " "
 
         return address[:-1]
@@ -70,6 +79,7 @@ class SetDestIP(OSCSetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/system-settings/#setdestip"""  # noqa
 
     address: str = field(default="/setDestIp", init=False)
+    response_cls: responses.DestIP = field(default=responses.DestIP, init=False)
 
 
 @dataclass
@@ -77,6 +87,7 @@ class GetVersion(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/system-settings/#getversion"""  # noqa
 
     address: str = field(default="/getVersion", init=False)
+    response_cls: responses.Version = field(default=responses.Version, init=False)
 
 
 @dataclass
@@ -84,6 +95,7 @@ class GetConfigName(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/system-settings/#getconfigname"""  # noqa
 
     address: str = field(default="/getConfigName", init=False)
+    response_cls: responses.ConfigName = field(default=responses.ConfigName, init=False)
 
 
 @dataclass
@@ -91,7 +103,19 @@ class ReportError(OSCSetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/system-settings/#reporterror_boolenable"""  # noqa
 
     address: str = field(default="/reportError", init=False)
+    response_cls: Tuple[responses.ErrorCommand, responses.ErrorOSC] = field(
+        default_factory=lambda: (responses.ErrorCommand, responses.ErrorOSC), init=False
+    )
     enable: bool
+    callback: Optional[Callable[..., None]] = None
+
+
+@dataclass
+class ResetDevice(OSCSetCommand):
+    """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/system-settings/#resetdevice"""  # noqa
+
+    address: str = field(default="/resetDevice", init=False)
+    response_cls: responses.Booted = field(default=responses.Booted, init=False)
 
 
 # Motor Driver Settings
@@ -111,6 +135,9 @@ class GetMicrostepMode(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/motor-driver-settings/#setmicrostepmode_intmotorid_intstep_sel"""  # noqa
 
     address: str = field(default="/getMicrostepMode", init=False)
+    response_cls: responses.MicrostepMode = field(
+        default=responses.MicrostepMode, init=False
+    )
     motorID: int
 
 
@@ -119,6 +146,9 @@ class EnableLowSpeedOptimize(OSCSetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/motor-driver-settings/#enablelowspeedoptimize_intmotorid_boolenable"""  # noqa
 
     address: str = field(default="/enableLowSpeedOptimize", init=False)
+    response_cls: responses.LowSpeedOptimizeThreshold = field(
+        default=responses.LowSpeedOptimizeThreshold, init=False
+    )
     motorID: int
     enable: bool
 
@@ -137,6 +167,9 @@ class GetLowSpeedOptimizeThreshold(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/motor-driver-settings/#getlowspeedoptimizethreshold_intmotorid"""  # noqa
 
     address: str = field(default="/getLowSpeedOptimizeThreshold", init=False)
+    response_cls: responses.LowSpeedOptimizeThreshold = field(
+        default=responses.LowSpeedOptimizeThreshold, init=False
+    )
     motorID: int
 
 
@@ -145,8 +178,10 @@ class EnableBusyReport(OSCSetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/motor-driver-settings/#enablebusyreport_intmotorid_boolenable"""  # noqa
 
     address: str = field(default="/enableBusyReport", init=False)
+    response_cls: responses.Busy = field(default=responses.Busy, init=False)
     motorID: int
     enable: bool
+    callback: Optional[Callable[..., None]] = None
 
 
 @dataclass
@@ -154,6 +189,7 @@ class GetBusy(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/motor-driver-settings/#getbusy_intmotorid"""  # noqa
 
     address: str = field(default="/getBusy", init=False)
+    response_cls: responses.Busy = field(default=responses.Busy, init=False)
     motorID: int
 
 
@@ -162,8 +198,10 @@ class EnableHiZReport(OSCSetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/motor-driver-settings/#enablehizreport_intmotorid_boolenable"""  # noqa
 
     address: str = field(default="/enableHizReport", init=False)
+    response_cls: responses.HiZ = field(default=responses.HiZ, init=False)
     motorID: int
     enable: bool
+    callback: Optional[Callable[..., None]] = None
 
 
 @dataclass
@@ -171,6 +209,27 @@ class GetHiZ(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/motor-driver-settings/#gethiz_intmotorid"""  # noqa
 
     address: str = field(default="/getHiZ", init=False)
+    response_cls: responses.HiZ = field(default=responses.HiZ, init=False)
+    motorID: int
+
+
+@dataclass
+class EnableDirReport(OSCSetCommand):
+    """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/motor-driver-settings/#enabledirreport_intmotorid_boolenable"""  # noqa
+
+    address: str = field(default="/enableDirReport", init=False)
+    response_cls: responses.Dir = field(default=responses.Dir, init=False)
+    motorID: int
+    enable: bool
+    callback: Optional[Callable[..., None]] = None
+
+
+@dataclass
+class GetDir(OSCGetCommand):
+    """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/motor-driver-settings/#getdir_intmotorid"""  # noqa
+
+    address: str = field(default="/getDir", init=False)
+    response_cls: responses.Dir = field(default=responses.Dir, init=False)
     motorID: int
 
 
@@ -179,8 +238,12 @@ class EnableMotorStatusReport(OSCSetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/motor-driver-settings/#enablemotorstatusreport_intmotorid_boolenable"""  # noqa
 
     address: str = field(default="/enableMotorStatusReport", init=False)
+    response_cls: responses.MotorStatus = field(
+        default=responses.MotorStatus, init=False
+    )
     motorID: int
     enable: bool
+    callback: Optional[Callable[..., None]] = None
 
 
 @dataclass
@@ -188,14 +251,41 @@ class GetMotorStatus(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/motor-driver-settings/#getmotorstatus_intmotorid"""  # noqa
 
     address: str = field(default="/getMotorStatus", init=False)
+    response_cls: responses.MotorStatus = field(
+        default=responses.MotorStatus, init=False
+    )
     motorID: int
 
 
+@dataclass
+class SetPositionReportInterval(OSCSetCommand):
+    """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/motor-driver-settings/#setpositionreportinterval_intmotorid_intinterval"""  # noqa
+
+    address: str = field(default="/setPositionReportInterval", init=False)
+    response_cls: responses.Position = field(default=responses.Position, init=False)
+    motorID: int
+    interval: int
+    callback: Optional[Callable[..., None]] = None
+
+
+@dataclass
+class SetPositionListReportInterval(OSCSetCommand):
+    """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/motor-driver-settings/#setpositionlistreportinterval_intinterval"""  # noqa
+
+    address: str = field(default="/setPositionListReportInterval", init=False)
+    response_cls: responses.PositionList = field(
+        default=responses.PositionList, init=False
+    )
+    interval: int
+    callback: Optional[Callable[..., None]] = None
+
+
 @dataclass
 class GetAdcVal(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/motor-driver-settings/#getadcval_intmotorid"""  # noqa
 
     address: str = field(default="/getAdcVal", init=False)
+    response_cls: responses.AdcVal = field(default=responses.AdcVal, init=False)
     motorID: int
 
 
@@ -204,6 +294,7 @@ class GetStatus(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/motor-driver-settings/#getstatus_intmotorid"""  # noqa
 
     address: str = field(default="/getStatus", init=False)
+    response_cls: responses.Status = field(default=responses.Status, init=False)
     motorID: int
 
 
@@ -212,6 +303,9 @@ class GetConfigRegister(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/motor-driver-settings/#getconfigregister_intmotorid"""  # noqa
 
     address: str = field(default="/getConfigRegister", init=False)
+    response_cls: responses.ConfigRegister = field(
+        default=responses.ConfigRegister, init=False
+    )
     motorID: int
 
 
@@ -231,8 +325,10 @@ class EnableUvloReport(OSCSetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/alarm-settings/#enableuvloreport_intmotorid_boolenable"""  # noqa
 
     address: str = field(default="/enableUvloReport", init=False)
+    response_cls: responses.Uvlo = field(default=responses.Uvlo, init=False)
     motorID: int
     enable: bool
+    callback: Optional[Callable[..., None]] = None
 
 
 @dataclass
@@ -240,6 +336,7 @@ class GetUvlo(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/alarm-settings/#getuvlo_intmotorid"""  # noqa
 
     address: str = field(default="/getUvlo", init=False)
+    response_cls: responses.Uvlo = field(default=responses.Uvlo, init=False)
     motorID: int
 
 
@@ -248,8 +345,12 @@ class EnableThermalStatusReport(OSCSetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/alarm-settings/#enablethermalstatusreport_intmotorid_boolenable"""  # noqa
 
     address: str = field(default="/enableThermalStatusReport", init=False)
+    response_cls: responses.ThermalStatus = field(
+        default=responses.ThermalStatus, init=False
+    )
     motorID: int
     enable: bool
+    callback: Optional[Callable[..., None]] = None
 
 
 @dataclass
@@ -257,6 +358,9 @@ class GetThermalStatus(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/alarm-settings/#getthermalstatus_intmotorid"""  # noqa
 
     address: str = field(default="/getThermalStatus", init=False)
+    response_cls: responses.ThermalStatus = field(
+        default=responses.ThermalStatus, init=False
+    )
     motorID: int
 
 
@@ -265,8 +369,12 @@ class EnableOverCurrentReport(OSCSetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/alarm-settings/#enableovercurrentreport_intmotorid_boolenable"""  # noqa
 
     address: str = field(default="/enableOverCurrentReport", init=False)
+    response_cls: responses.OverCurrent = field(
+        default=responses.OverCurrent, init=False
+    )
     motorID: int
     enable: bool
+    callback: Optional[Callable[..., None]] = None
 
 
 @dataclass
@@ -283,6 +391,9 @@ class GetOverCurrentThreshold(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/alarm-settings/#getovercurrentthreshold_intmotorid"""  # noqa
 
     address: str = field(default="/getOverCurrentThreshold", init=False)
+    response_cls: responses.OverCurrentThreshold = field(
+        default=responses.OverCurrentThreshold, init=False
+    )
     motorID: int
 
 
@@ -291,8 +402,10 @@ class EnableStallReport(OSCSetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/alarm-settings/#enablestallreport_intmotorid_boolenable"""  # noqa
 
     address: str = field(default="/enableStallReport", init=False)
+    response_cls: responses.Stall = field(default=responses.Stall, init=False)
     motorID: int
     enable: bool
+    callback: Optional[Callable[..., None]] = None
 
 
 @dataclass
@@ -309,6 +422,9 @@ class GetStallThreshold(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/alarm-settings/#getstallthreshold_intmotorid"""  # noqa
 
     address: str = field(default="/getStallThreshold", init=False)
+    response_cls: responses.StallThreshold = field(
+        default=responses.StallThreshold, init=False
+    )
     motorID: int
 
 
@@ -326,6 +442,9 @@ class GetProhibitMotionOnHomeSw(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/alarm-settings/#getprohibitmotiononhomesw_intmotorid"""  # noqa
 
     address: str = field(default="/getProhibitMotionOnHomeSw", init=False)
+    response_cls: responses.ProhibitMotionOnHomeSw = field(
+        default=responses.ProhibitMotionOnHomeSw, init=False
+    )
     motorID: int
 
 
@@ -343,6 +462,9 @@ class GetProhibitMotionOnLimitSw(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/alarm-settings/#getprohibitmotiononlimitsw_intmotorid"""  # noqa
 
     address: str = field(default="/getProhibitMotionOnLimitSw", init=False)
+    response_cls: responses.ProhibitMotionOnLimitSw = field(
+        default=responses.ProhibitMotionOnLimitSw, init=False
+    )
     motorID: int
 
 
@@ -374,6 +496,7 @@ class GetKval(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/voltage-and-current-mode-settings/#getkval_intmotorid"""  # noqa
 
     address: str = field(default="/getKval", init=False)
+    response_cls: responses.Kval = field(default=responses.Kval, init=False)
     motorID: int
 
 
@@ -394,6 +517,7 @@ class GetBemfParam(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/voltage-and-current-mode-settings/#getbemfparam_intmotorid"""  # noqa
 
     address: str = field(default="/getBemfParam", init=False)
+    response_cls: responses.BemfParam = field(default=responses.BemfParam, init=False)
     motorID: int
 
 
@@ -422,6 +546,16 @@ class GetTval(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/voltage-and-current-mode-settings/#gettval_intmotorid"""  # noqa
 
     address: str = field(default="/getTval", init=False)
+    response_cls: responses.Tval = field(default=responses.Tval, init=False)
+    motorID: int
+
+
+@dataclass
+class GetTval_mA(OSCGetCommand):
+    """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/voltage-and-current-mode-settings/#gettval_ma_intmotorid"""  # noqa
+
+    address: str = field(default="/getTval_mA", init=False)
+    response_cls: responses.Tval_mA = field(default=responses.Tval_mA, init=False)
     motorID: int
 
 
@@ -441,6 +575,9 @@ class GetDecayModeParam(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/voltage-and-current-mode-settings/#getdecaymodeparam_intmotorid"""  # noqa
 
     address: str = field(default="/getDecayModeParam", init=False)
+    response_cls: responses.DecayModeParam = field(
+        default=responses.DecayModeParam, init=False
+    )
     motorID: int
 
 
@@ -463,6 +600,9 @@ class GetSpeedProfile(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/speed-profile/#getspeedprofile_intmotorid"""  # noqa
 
     address: str = field(default="/getSpeedProfile", init=False)
+    response_cls: responses.SpeedProfile = field(
+        default=responses.SpeedProfile, init=False
+    )
     motorID: int
 
 
@@ -480,6 +620,9 @@ class GetFullstepSpeed(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/speed-profile/#getfullstepspeed_intmotorid"""  # noqa
 
     address: str = field(default="/getFullstepSpeed", init=False)
+    response_cls: responses.FullstepSpeed = field(
+        default=responses.FullstepSpeed, init=False
+    )
     motorID: int
 
 
@@ -524,6 +667,7 @@ class GetMinSpeed(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/speed-profile/#getminspeed_intmotorid"""  # noqa
 
     address: str = field(default="/getMinSpeed", init=False)
+    response_cls: responses.MinSpeed = field(default=responses.MinSpeed, init=False)
     motorID: int
 
 
@@ -532,6 +676,7 @@ class GetSpeed(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/speed-profile/#getspeed_intmotorid"""  # noqa
 
     address: str = field(default="/getSpeed", init=False)
+    response_cls: responses.Speed = field(default=responses.Speed, init=False)
     motorID: int
 
 
@@ -551,6 +696,9 @@ class GetHomingStatus(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/homing/#sethomingdirection_intmotorid_booldirection"""  # noqa
 
     address: str = field(default="/getHomingStatus", init=False)
+    response_cls: responses.HomingStatus = field(
+        default=responses.HomingStatus, init=False
+    )
     motorID: int
 
 
@@ -568,6 +716,9 @@ class GetHomingDirection(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/homing/#gethomingdirection_intmotorid"""  # noqa
 
     address: str = field(default="/getHomingDirection", init=False)
+    response_cls: responses.HomingDirection = field(
+        default=responses.HomingDirection, init=False
+    )
     motorID: int
 
 
@@ -585,6 +736,9 @@ class GetHomingSpeed(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/homing/#gethomingspeed_intmotorid"""  # noqa
 
     address: str = field(default="/getHomingSpeed", init=False)
+    response_cls: responses.HomingSpeed = field(
+        default=responses.HomingSpeed, init=False
+    )
     motorID: int
 
 
@@ -612,6 +766,9 @@ class GetGoUntilTimeout(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/homing/#getgountiltimeout_intmotorid"""  # noqa
 
     address: str = field(default="/getGoUntilTimeout", init=False)
+    response_cls: responses.GoUntilTimeout = field(
+        default=responses.GoUntilTimeout, init=False
+    )
     motorID: int
 
 
@@ -639,6 +796,9 @@ class GetReleaseSwTimeout(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/homing/#setreleaseswtimeout_intmotorid_inttimeout"""  # noqa
 
     address: str = field(default="/getReleaseSwTimeout", init=False)
+    response_cls: responses.ReleaseSwTimeout = field(
+        default=responses.ReleaseSwTimeout, init=False
+    )
     motorID: int
 
 
@@ -650,8 +810,10 @@ class EnableHomeSwReport(OSCSetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/home-and-limit-sensers/#enablehomeswreport_intmotorid_boolenable"""  # noqa
 
     address: str = field(default="/enableHomeSwReport", init=False)
+    response_cls: responses.HomeSw = field(default=responses.HomeSw, init=False)
     motorID: int
     enable: bool
+    callback: Optional[Callable[..., None]] = None
 
 
 @dataclass
@@ -659,8 +821,10 @@ class EnableSwEventReport(OSCSetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/home-and-limit-sensers/#enablesweventreport_intmotorid_boolenable"""  # noqa
 
     address: str = field(default="/enableSwEventReport", init=False)
+    response_cls: responses.SwEvent = field(default=responses.SwEvent, init=False)
     motorID: int
     enable: bool
+    callback: Optional[Callable[..., None]] = None
 
 
 @dataclass
@@ -668,6 +832,7 @@ class GetHomeSw(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/home-and-limit-sensers/#gethomesw_intmotorid"""  # noqa
 
     address: str = field(default="/getHomeSw", init=False)
+    response_cls: responses.HomeSw = field(default=responses.HomeSw, init=False)
     motorID: int
 
 
@@ -676,8 +841,10 @@ class EnableLimitSwReport(OSCSetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/home-and-limit-sensers/#enablelimitswreport_intmotorid_boolenable"""  # noqa
 
     address: str = field(default="/enableLimitSwReport", init=False)
+    response_cls: responses.LimitSw = field(default=responses.LimitSw, init=False)
     motorID: int
     enable: bool
+    callback: Optional[Callable[..., None]] = None
 
 
 @dataclass
@@ -685,6 +852,7 @@ class GetLimitSw(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/home-and-limit-sensers/#getlimitsw_intmotorid"""  # noqa
 
     address: str = field(default="/getLimitSw", init=False)
+    response_cls: responses.LimitSw = field(default=responses.LimitSw, init=False)
     motorID: int
 
 
@@ -702,6 +870,7 @@ class GetHomeSwMode(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/home-and-limit-sensers/#gethomeswmode_intmotorid"""  # noqa
 
     address: str = field(default="/getHomeSwMode", init=False)
+    response_cls: responses.HomeSwMode = field(default=responses.HomeSwMode, init=False)
     motorID: int
 
 
@@ -719,6 +888,9 @@ class GetLimitSwMode(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/home-and-limit-sensers/#getlimitswmode_intmotorid"""  # noqa
 
     address: str = field(default="/getLimitSwMode", init=False)
+    response_cls: responses.LimitSwMode = field(
+        default=responses.LimitSwMode, init=False
+    )
     motorID: int
 
 
@@ -739,9 +911,20 @@ class GetPosition(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/position-management/#getposition_intmotorid"""  # noqa
 
     address: str = field(default="/getPosition", init=False)
+    response_cls: responses.Position = field(default=responses.Position, init=False)
     motorID: int
 
 
+@dataclass
+class GetPositionList(OSCGetCommand):
+    """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/position-management/#getpositionlist"""  # noqa
+
+    address: str = field(default="/getPositionList", init=False)
+    response_cls: responses.PositionList = field(
+        default=responses.PositionList, init=False
+    )
+
+
 @dataclass
 class ResetPos(OSCSetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/position-management/#resetpos_intmotorid"""  # noqa
@@ -750,6 +933,25 @@ class ResetPos(OSCSetCommand):
     motorID: int
 
 
+@dataclass
+class SetElPos(OSCSetCommand):
+    """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/position-management/#setelpos_intmotorid_intnewfullstep_intnewmicrostep"""  # noqa
+
+    address: str = field(default="/setElPos", init=False)
+    motorID: int
+    newFullstep: int
+    newMicrostep: int
+
+
+@dataclass
+class GetElPos(OSCGetCommand):
+    """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/position-management/#getelpos_intmotorid"""  # noqa
+
+    address: str = field(default="/getElPos", init=False)
+    response_cls: responses.ElPos = field(default=responses.ElPos, init=False)
+    motorID: int
+
+
 @dataclass
 class SetMark(OSCSetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/position-management/#setmark_intmotorid_intmark"""  # noqa
@@ -764,6 +966,7 @@ class GetMark(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/position-management/#getmark_intmotorid"""  # noqa
 
     address: str = field(default="/getMark", init=False)
+    response_cls: responses.Mark = field(default=responses.Mark, init=False)
     motorID: int
 
 
@@ -899,6 +1102,9 @@ class GetBrakeTransitionDuration(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/brake/#getbraketransitionduration_intmotorid"""  # noqa
 
     address: str = field(default="/getBrakeTransitionDuration", init=False)
+    response_cls: responses.BrakeTransitionDuration = field(
+        default=responses.BrakeTransitionDuration, init=False
+    )
     motorID: int
 
 
@@ -930,6 +1136,7 @@ class GetServoParam(OSCGetCommand):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/servo-mode/#getservoparam_intmotorid"""  # noqa
 
     address: str = field(default="/getServoParam", init=False)
+    response_cls: responses.ServoParam = field(default=responses.ServoParam, init=False)
     motorID: int
 
 
@@ -951,3 +1158,7 @@ class SetTargetPositionList(OSCSetCommand):
     position2: int
     position3: int
     position4: int
+    position5: int = None
+    position6: int = None
+    position7: int = None
+    position8: int = None
