@@ -262,6 +262,15 @@ class LowSpeedOptimizeThreshold(OSCResponse):
     optimizationEnabled: bool
 
 
+@dataclass
+class Dir(OSCResponse):
+    """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/motor-driver-settings/#getdir_intmotorid"""  # noqa
+
+    address: str = field(default="/dir", init=False)
+    motorID: int
+    direction: bool
+
+
 @dataclass
 class AdcVal(OSCResponse):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/motor-driver-settings/#getadcval_intmotorid"""  # noqa
@@ -367,6 +376,18 @@ class Tval(OSCResponse):
     decTVAL: int
 
 
+@dataclass
+class Tval_mA(OSCResponse):
+    """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/voltage-and-current-mode-settings/#gettval_ma_intmotorid"""  # noqa
+
+    address: str = field(default="/tval_mA", init=False)
+    motorID: int
+    holdTVAL_mA: float
+    runTVAL_mA: float
+    accTVAL_mA: float
+    decTVAL_mA: float
+
+
 @dataclass
 class DecayModeParam(OSCResponse):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/voltage-and-current-mode-settings/#getdecaymodeparam_intmotorid"""  # noqa
@@ -519,6 +540,31 @@ class Position(OSCResponse):
     ABS_POS: int
 
 
+@dataclass
+class PositionList(OSCResponse):
+    """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/position-management/#getpositionlist"""  # noqa
+
+    address: str = field(default="/positionList", init=False)
+    position1: int
+    position2: int
+    position3: int
+    position4: int
+    position5: int = None
+    position6: int = None
+    position7: int = None
+    position8: int = None
+
+
+@dataclass
+class ElPos(OSCResponse):
+    """Documentation https://ponoor.com/en/docs/step-series/osc-command-reference/position-management/#getelpos_intmotorid"""  # noqa
+
+    address: str = field(default="/elPos", init=False)
+    motorID: int
+    fullstep: int
+    microstep: int
+
+
 @dataclass
 class Mark(OSCResponse):
     """Documentation: https://ponoor.com/en/docs/step-series/osc-command-reference/position-management/#getmark_intmotorid"""  # noqa
